==> kubernetes-model-1.0.54-sources.jar: io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class HorizontalPodAutoscalerBuilder extends HorizontalPodAutoscalerFluentImpl<HorizontalPodAutoscalerBuilder> implements VisitableBuilder<HorizontalPodAutoscaler,HorizontalPodAutoscalerBuilder>{

    HorizontalPodAutoscalerFluent<?> fluent;
    Boolean validationEnabled;

    public HorizontalPodAutoscalerBuilder(){
            this(true);
    }
    public HorizontalPodAutoscalerBuilder(Boolean validationEnabled){
            this(new HorizontalPodAutoscaler(), validationEnabled);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent){
            this(fluent, true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new HorizontalPodAutoscaler(), validationEnabled);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,HorizontalPodAutoscaler instance){
            this(fluent, instance, true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,HorizontalPodAutoscaler instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSpec(instance.getSpec()); 
            fluent.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscaler instance){
            this(instance,true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscaler instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }

    public HorizontalPodAutoscaler build(){
            HorizontalPodAutoscaler buildable = new HorizontalPodAutoscaler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HorizontalPodAutoscalerBuilder that = (HorizontalPodAutoscalerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/extensions/HorizontalPodAutoscalerBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class HorizontalPodAutoscalerBuilder extends HorizontalPodAutoscalerFluentImpl<HorizontalPodAutoscalerBuilder> implements VisitableBuilder<HorizontalPodAutoscaler,HorizontalPodAutoscalerBuilder>{

    HorizontalPodAutoscalerFluent<?> fluent;
    Boolean validationEnabled;

    public HorizontalPodAutoscalerBuilder(){
            this(true);
    }
    public HorizontalPodAutoscalerBuilder(Boolean validationEnabled){
            this(new HorizontalPodAutoscaler(), validationEnabled);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent){
            this(fluent, true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new HorizontalPodAutoscaler(), validationEnabled);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,HorizontalPodAutoscaler instance){
            this(fluent, instance, true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscalerFluent<?> fluent,HorizontalPodAutoscaler instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            fluent.withSpec(instance.getSpec()); 
            fluent.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscaler instance){
            this(instance,true);
    }
    public HorizontalPodAutoscalerBuilder(HorizontalPodAutoscaler instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withSpec(instance.getSpec()); 
            this.withStatus(instance.getStatus()); 
            this.validationEnabled = validationEnabled; 
    }

    public HorizontalPodAutoscaler build(){
            HorizontalPodAutoscaler buildable = new HorizontalPodAutoscaler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HorizontalPodAutoscalerBuilder that = (HorizontalPodAutoscalerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
